@@ -144,7 +144,7 @@ class Model:
         """
         return self._data.__getitem__(key)
 
-    def add_file(self, file: ParPath, parse_data: bool = True) -> None:
+    def add_file(self, file: ParPath, parse_data: bool = False) -> None:
         """Adds a MiniZinc file (``.mzn``, ``.dzn``, or ``.json``) to the Model.
 
         Args:
@@ -173,17 +173,18 @@ class Model:
 
                 from .dzn import parse_dzn
 
-                data = parse_dzn(file)
-                for k, v in data.items():
-                    self.__setitem__(k, v)
-            except LarkError:
-                warnings.warn(
-                    f"Could not parse {file}. Parameters included within this file are "
-                    f"not available in Python"
-                )
+                try:
+                    data = parse_dzn(file)
+                    for k, v in data.items():
+                        self.__setitem__(k, v)
+                except LarkError:
+                    warnings.warn(
+                        f"Could not parse {file}. Parameters included within this file "
+                        f"are not available in Python"
+                    )
+                    with self._lock:
+                        self._includes.append(file)
             except ImportError:
-                pass
-            finally:
                 with self._lock:
                     self._includes.append(file)
         elif file.suffix not in [".dzn", ".mzn", ".mzc"]:
