@@ -6,7 +6,7 @@ import contextlib
 import json
 import os
 import tempfile
-from dataclasses import dataclass, field
+from dataclasses import dataclass, field, fields
 from pathlib import Path
 from typing import Any, Dict, Iterator, List, Optional, Set, Tuple
 
@@ -62,6 +62,8 @@ class Solver:
             to use"). The third string specifies the type of the argument
             (``int``, ``bool``, ``float`` or ``string``). The fourth string is
             the default value.
+        requiredFlags (List[str]):  *Currently undocumented in the MiniZinc
+            documentation.*
         supportsMzn (bool): Whether the solver can run MiniZinc directly (i.e.,
             it implements its own compilation or interpretation of the model).
         supportsFzn (bool): Whether the solver can run FlatZinc. This should be
@@ -96,6 +98,7 @@ class Solver:
     tags: List[str] = field(default_factory=list)
     stdFlags: List[str] = field(default_factory=list)
     extraFlags: List[Tuple[str, str, str, str]] = field(default_factory=list)
+    requiredFlags: List[str] = field(default_factory=list)
     supportsMzn: bool = False
     supportsFzn: bool = True
     supportsNL: bool = False
@@ -155,8 +158,10 @@ class Solver:
                 f"{sorted([x for x in names])}"
             )
 
-        lookup.pop("extraInfo", None)
-        ret = cls(**lookup)
+        allowed_fields = set([f.name for f in fields(cls)])
+        ret = cls(
+            **{key: value for (key, value) in lookup.items() if key in allowed_fields}
+        )
         if ret.version == "<unknown version>":
             ret._identifier = ret.id
         else:
@@ -172,8 +177,6 @@ class Solver:
 
         Args:
             path (str): location to the solver configuration file to be loaded.
-            driver (Driver): driver used to load the solver configuration. If
-                set to None, then ``default_driver`` will be used.
 
         Returns:
             Solver: MiniZinc solver configuration compatible with the driver.
